@@ -27,12 +27,14 @@
 #include <QList>
 #include <QHash>
 
+class AutomounterSettings;
+
 class DeviceModel : public QAbstractItemModel
 {
     Q_OBJECT
 
 public:
-    explicit DeviceModel(QObject *parent = nullptr);
+    explicit DeviceModel(AutomounterSettings *m_settings, QObject *parent = nullptr);
     ~DeviceModel() override = default;
 
     enum DeviceType {
@@ -57,6 +59,9 @@ public:
 
     bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
 
+    void setAutomaticMountOnLogin(bool automaticLogin);
+    void setAutomaticMountOnPlugin(bool automaticAttached);
+
 public slots:
     void forgetDevice(const QString &udi);
     void reload();
@@ -72,6 +77,9 @@ private:
     QList<QString> m_disconnected;
     QHash<QString, bool> m_loginForced;
     QHash<QString, bool> m_attachedForced;
+    bool m_automaticLogin;
+    bool m_automaticAttached;
+    AutomounterSettings *m_settings;
 };
 
 #endif
